require 'spec_helper'

describe 'ResourcePage' do
  before(:example) do
    @page = CyberCoach::User.read_all
  end

  it 'should have meta data' do
    expect(@page.resources.size).to eq(5)
    expect(@page.start).to eq(0)
    expect(@page.end).to eq(5)
    expect(@page.available).to be > 5
    expect(@page.type).to eq(CyberCoach::User)
  end

  it 'should have resources of its type' do
    type = @page.type
    @page.resources.each do |item|
      expect(item).to be_a_kind_of(type)
    end
  end

  it 'should need :type to instantiate' do
    expect { CyberCoach::ResourcePage.new }.to raise_error(ArgumentError)
  end

  it 'should instantiate itself with preset attributes' do
    uri = '/pants/'
    type = CyberCoach::User
    start = 1
    end_ = 6
    size = 5
    pants = 'yes'
    @page = CyberCoach::ResourcePage.new(
      uri: uri,
      type: type,
      start: start,
      end: end_,
      size: size,
      pants: pants
    )
    expect(@page.uri).to be(uri)
    expect(@page.type).to be(type)
    expect(@page.start).to be(start)
    expect(@page.end).to be(end_)
    expect(@page.size).to be(size)
    expect { @page.pants }.to raise_error(NoMethodError)
  end

  it 'should read itself' do
    @page.start = 1
    @page.size = 2
    @page.read
    expect(@page.resources.size).to eq(2)
    expect(@page.start).to eq(1)
    expect(@page.end).to eq(3)
  end

  it 'should not invalidate when reading' do
    start = @page.start
    size = @page.size
    @page.start = 5
    @page.size = 6
    expect(@page.size).not_to eq(size)
    expect(@page.start).not_to eq(start)
    @page.read({}, false)
    expect(@page.size).to eq(size)
    expect(@page.start).to eq(start)
  end

  it 'should be able to navigate between pages' do
    expect { @page.previous }.to raise_error(CyberCoach::ResourcePage::NoPreviousPageError)
    next_page = @page.next
    expect(next_page.resources).not_to be_empty
    expect(next_page.start).to eq(@page.end)
    expect(next_page.end).to eq(next_page.start + 5)
    expect(next_page.available).to eq(@page.available)
    expect(next_page.type).to eq(@page.type)
    expect(next_page.resources[0].uri).not_to eq(@page.resources[0].uri)
    next_previous_page = next_page.previous
    expect(next_previous_page.resources[0].uri).to eq(@page.resources[0].uri)
  end
end
