require 'spec_helper'

describe 'Sport' do
  before(:example) do
    @sport = CyberCoach::Sport.new
  end

  it 'should instantiate itself with preset attributes' do
    uri = '/pants/'
    id = 1
    name = 'pants'
    description = 'very fancy'
    pants = 'yes'
    @sport = CyberCoach::Sport.new(
      uri: uri,
      id: id,
      name: name,
      description: description,
      pants: pants
    )
    expect(@sport.uri).to be(uri)
    expect(@sport.id).to be(id)
    expect(@sport.name).to be(name)
    expect(@sport.description).to be(description)
    expect { @sport.pants }.to raise_error(NoMethodError)
  end

  it 'should read itself' do
    @sport.name = 'Running'
    @sport.read
    expect(@sport.id).not_to be_nil
    expect(@sport.uri).not_to be_nil
    expect(@sport.name).not_to be_nil
    expect(@sport.description).not_to be_nil
    expect(@sport.subscriptions).not_to be_empty
  end

  it 'should not invalidate when reading' do
    @sport.name = 'Running'
    @sport.read
    name = @sport.name
    @sport.name = 'notTheName'
    expect(@sport.name).not_to eq(name)
    expect { @sport.read({}, false) }.not_to raise_error
    @sport.name = name
  end

  it 'should raise an error if it does not exist' do
    @sport.name = 'Pants'
    expect { @sport.read }.to raise_error(CyberCoach::HttpError)
  end

  it 'should read all' do
    sports = CyberCoach::Sport.read_all
    expect(sports.resources.size).to eq(4)
    expect { sports.next }.to raise_error(CyberCoach::ResourcePage::NoNextPageError)
    expect { sports.previous }.to raise_error(CyberCoach::ResourcePage::NoPreviousPageError)
  end
end
