require 'spec_helper'

describe 'Integration' do
  before(:context) do
    @proposer = UserHelper.make(8)
    @proposed = UserHelper.make(9)
    ResourceHelper.safe_delete(@proposer)
    ResourceHelper.safe_delete(@proposed)
    @proposer.create
    @proposed.create
    @partnership = CyberCoach::Partnership.new
    @partnership.proposer = @proposer
    @partnership.proposed = @proposed
    @partnership.privacy_level = CyberCoach::PrivacyLevel::REGISTERED_USER
    ResourceHelper.safe_delete(@partnership, @proposer.authentication)
    ResourceHelper.safe_delete(@partnership, @proposed.authentication)
    @partnership.create(@proposer.authentication)
    @partnership.update(@proposed.authentication)
    @sport = CyberCoach::Sport.new
    @sport.name = 'Running'
    @sport.read
    @subscription = CyberCoach::Subscription.new
    @subscription.subscriber = @partnership
    @subscription.sport = @sport
    @subscription.privacy_level = CyberCoach::PrivacyLevel::REGISTERED_USER
    @subscription.create(@proposer.authentication)
    @entry = CyberCoach::Entry.new
    @entry.subscription = @subscription
    @entry.comment = 'I like pants'
    @entry.location = 'In your pants'
    @entry.duration = 1
    @entry.privacy_level = CyberCoach::PrivacyLevel::REGISTERED_USER
    @entry.create(@proposer.authentication)
  end

  after(:context) do
    ResourceHelper.safe_delete(@entry, @proposer.authentication)
    ResourceHelper.safe_delete(@subscription, @proposer.authentication)
    ResourceHelper.safe_delete(@partnership, @proposer.authentication)
    ResourceHelper.safe_delete(@partnership, @proposed.authentication)
    ResourceHelper.safe_delete(@proposer)
    ResourceHelper.safe_delete(@proposed)
  end

  it 'should add the subscription to the partnership' do
    @partnership.read(@proposer.authentication)
    expect(@partnership.subscriptions).not_to be_empty
    expect(@partnership.subscriptions[0].uri).to eq(@subscription.uri)
  end

  it 'should add the entry to the subscription' do
    @subscription.read(@proposer.authentication)
    expect(@subscription.entries).not_to be_empty
    expect(@subscription.entries[0].uri).to eq(@entry.uri)
  end
end
